/*
 * sbug.h - Debugger functions
 *
 * Written 2003 by Werner Almesberger, Caltech Netlab FAST project
 */

#ifndef SBUG_H
#define SBUG_H

#include "dwarfx.h"
#include "ptrace.h"

#include "data.h"
#include "op.h"
#include "stmt.h"


extern int sbug;


struct process;
struct breakpoint;
struct object;


/* ----- data.h ------------------------------------------------------------ */


extern struct dwx_type process_type;
extern struct dwx_type breakpoint_type;
extern struct dwx_type object_type;

struct value *process_value(struct process *process);
struct process *__value_process(struct value *value);

struct value *breakpoint_value(struct breakpoint *breakpoint);
struct breakpoint *__value_breakpoint(struct value *value);

struct value *object_value(struct object *obj);
const struct object *__value_object(struct value *value);

int sbug_put(struct value *value);


/* ----- op.h -------------------------------------------------------------- */


struct value *op_run(const struct op *self);
struct value *op_breakpoint(const struct op *self);
struct value *op_object(const struct op *self);

int destroy_sbug_op(const struct op *stmt);


/* ----- stmt.h ------------------------------------------------------------ */


void stmt_continue_process(const struct stmt *self);

int destroy_sbug_stmt(const struct stmt *stmt);


/* ----- Data access ------------------------------------------------------- */


struct value *dereference_object(struct value *value);


/* ----- Other functions --------------------------------------------------- */

int sbug_main(int argc,char **argv);

#endif /* SBUG_H */
